@@ -732,7 +732,7 @@ class LidarChannel(object):
         background = np.mean(self.matrix[:, idx_min:idx_max], axis=1)
         background_corrected = (self.matrix.transpose() - background).transpose()
         background_corrected = np.roll(background_corrected, -first_signal_bin, axis=1)
-        background_corrected[:, -9:] = 0
+        background_corrected[:, -first_signal_bin:] = 0
         self.rc = background_corrected * (self.z ** 2)
 
     def noise_mask(self, idx_min=-2000, idx_max=-500, threshold=1.):
