@@ -723,6 +723,9 @@ class FixedPointingFile(LicelFile):
     """ Raymetrics is using a custom version of licel file format to store
     vertical lidar measurements.
 
+    `azimuth_angle`
+        The angle from North
+
     `temperature`
         Ambient temperature (degrees C)
 
@@ -737,13 +740,27 @@ class FixedPointingFile(LicelFile):
 
     fix_zenith_angle = True
 
+    def __init__(self, file_path, use_id_as_name=False, get_name_by_order=False, licel_timezone="UTC", import_now=True, azimuth_offset=0):
+        self.azimuth_offset = azimuth_offset
+
+        super().__init__(file_path, use_id_as_name=use_id_as_name, get_name_by_order=get_name_by_order,
+                         licel_timezone=licel_timezone, import_now=import_now)
+
     def _assign_properties(self):
         """ Assign scanning-specific parameters found in the header as object properties."""
         super(FixedPointingFile, self)._assign_properties()
 
         self.temperature = float(self.raw_info['temperature'])
         self.pressure = float(self.raw_info['pressure'])
-        self.azimuth_angle = float(self.raw_info['azimuth_angle'])
+        self.azimuth_angle_raw = float(self.raw_info['azimuth_angle'])
+
+        azimuth_offset = getattr(self, 'azimuth_offset', None)
+
+        # Add a option to manually define an azimuth offset, but still work if you don't
+        if azimuth_offset is not None:
+            self.azimuth_angle = (self.azimuth_angle_raw + azimuth_offset) % 360
+        else:
+            self.azimuth_angle = self.azimuth_angle_raw
 
 
 class FixedPointingChannel(LicelChannel):
